@@ -1,7 +1,7 @@
 // qsynthMainForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -44,7 +44,6 @@
 #include <QMessageBox>
 #include <QSettings>
 #include <QDateTime>
-#include <QRegExp>
 #include <QTimer>
 #include <QMenu>
 #include <QUrl>
@@ -77,8 +76,8 @@ const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
 #define QSYNTH_MASTER_GAIN_SCALE    100.0f
 
 #define QSYNTH_REVERB_ROOM_SCALE    100.0f
-#define QSYNTH_REVERB_DAMP_SCALE	100.0f
-#define QSYNTH_REVERB_WIDTH_SCALE   1.0f
+#define QSYNTH_REVERB_DAMP_SCALE    100.0f
+#define QSYNTH_REVERB_WIDTH_SCALE   100.0f
 #define QSYNTH_REVERB_LEVEL_SCALE   100.0f
 
 #define QSYNTH_CHORUS_NR_SCALE      1.0f
@@ -125,7 +124,7 @@ static void qsynth_sigterm_handler ( int /* signo */ )
 
 // Needed for lroundf()
 #ifdef CONFIG_ROUND
-#include <math.h>
+#include <QtMath>
 #else
 static inline long lroundf ( float x )
 {
@@ -852,7 +851,11 @@ void qsynthMainForm::closeEvent ( QCloseEvent *pCloseEvent )
 	// Let's be sure about that...
 	if (queryClose()) {
 		pCloseEvent->accept();
+	#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+		QApplication::exit(0);
+	#else
 		QApplication::quit();
+	#endif
 	} else {
 		pCloseEvent->ignore();
 	}
@@ -860,8 +863,8 @@ void qsynthMainForm::closeEvent ( QCloseEvent *pCloseEvent )
 
 
 // Add dropped files to playlist or soundfont stack.
-void qsynthMainForm::playLoadFiles ( qsynthEngine *pEngine,
-	const QStringList& files, bool bSetup )
+void qsynthMainForm::playLoadFiles (
+	qsynthEngine *pEngine, const QStringList& files, bool bSetup )
 {
 	if (pEngine == nullptr)
 		return;
@@ -901,17 +904,37 @@ void qsynthMainForm::playLoadFiles ( qsynthEngine *pEngine,
 			}
 		}
 		else  // Or is it a bare midifile?
-		if (::fluid_is_midifile(sFilename.toLocal8Bit().data()) && pEngine->pPlayer) {
-			appendMessagesColor(sPrefix +
-				tr("Playing MIDI file: \"%1\"")
-				.arg(sFilename) + sElipsis, "#99cc66");
-			if (::fluid_player_add(
-					pEngine->pPlayer, sFilename.toLocal8Bit().data()) >= 0) {
-				iMidiFiles++;
-			} else {
-				appendMessagesError(sPrefix +
-					tr("Failed to play MIDI file: \"%1\".")
-					.arg(sFilename));
+		if (::fluid_is_midifile(sFilename.toLocal8Bit().data())) {
+			// Destroy the MIDI player, if done already...
+			if (pEngine->pPlayer &&
+				::fluid_player_get_status(pEngine->pPlayer) == FLUID_PLAYER_DONE) {
+				appendMessages(sPrefix + tr("Destroying MIDI player") + sElipsis);
+				::delete_fluid_player(pEngine->pPlayer);
+				pEngine->pPlayer = nullptr;
+			}
+			// Create the MIDI player, if not already...
+			if (pEngine->pPlayer == nullptr) {
+				appendMessages(sPrefix + tr("Creating MIDI player") + sElipsis);
+				pEngine->pPlayer = ::new_fluid_player(pEngine->pSynth);
+				if (pEngine->pPlayer == nullptr) {
+					appendMessagesError(sPrefix +
+						tr("Failed to create the MIDI player.\n\n"
+						"Continuing without a player."));
+				}
+			}
+			// Add file to the MIDI player play-list...
+			if (pEngine->pPlayer) {
+				appendMessagesColor(sPrefix +
+					tr("Playing MIDI file: \"%1\"")
+					.arg(sFilename) + sElipsis, "#99cc66");
+				if (::fluid_player_add(
+						pEngine->pPlayer, sFilename.toLocal8Bit().data()) >= 0) {
+					iMidiFiles++;
+				} else {
+					appendMessagesError(sPrefix +
+						tr("Failed to play MIDI file: \"%1\".")
+						.arg(sFilename));
+				}
 			}
 		}
 	}
@@ -923,8 +946,10 @@ void qsynthMainForm::playLoadFiles ( qsynthEngine *pEngine,
 	}
 
 	// Start playing, if any...
-	if (pEngine->pPlayer && iMidiFiles > 0)
+	if (pEngine->pPlayer && iMidiFiles > 0) {
+		::fluid_player_set_loop(pEngine->pPlayer, 1);
 		::fluid_player_play(pEngine->pPlayer);
+	}
 }
 
 
@@ -992,6 +1017,11 @@ void qsynthMainForm::sigtermNotifySlot ( int /* fd */ )
 }
 
 
+#if defined(Q_CC_GNU) || defined(Q_CC_MINGW)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-parameter"
+#endif
+
 // Set stdout/stderr blocking mode.
 bool qsynthMainForm::stdoutBlock ( int fd, bool bBlock ) const
 {
@@ -1030,6 +1060,10 @@ void qsynthMainForm::stdoutNotifySlot ( int fd )
 #endif
 }
 
+#if defined(Q_CC_GNU) || defined(Q_CC_MINGW)
+#pragma GCC diagnostic pop
+#endif
+
 
 // Stdout buffer handler -- now splitted by complete new-lines...
 void qsynthMainForm::appendStdoutBuffer ( const QString& s )
@@ -1509,7 +1543,7 @@ void qsynthMainForm::toggleMainForm (void)
 
 	m_pOptions->saveWidgetGeometry(this, true);
 
-	if (isVisible() && !isMinimized() && isActiveWindow()) {
+	if (isVisible() && !isMinimized()) {
 	#ifdef CONFIG_SYSTEM_TRAY
 		// Hide away from sight, totally...
 		if (m_pOptions->bSystemTray && m_pSystemTray)
@@ -1519,6 +1553,7 @@ void qsynthMainForm::toggleMainForm (void)
 		// Minimize (iconify) normally.
 		showMinimized();
 	} else {
+		// Show normally.
 		showNormal();
 		raise();
 		activateWindow();
@@ -1955,18 +1990,6 @@ bool qsynthMainForm::startEngine ( qsynthEngine *pEngine )
 		}
 	}
 
-	// Create the MIDI player.
-	appendMessages(sPrefix + tr("Creating MIDI player") + sElipsis);
-	pEngine->pPlayer = ::new_fluid_player(pEngine->pSynth);
-	if (pEngine->pPlayer == nullptr) {
-		appendMessagesError(sPrefix +
-			tr("Failed to create the MIDI player.\n\n"
-			"Continuing without a player."));
-	} else {
-		// Play the midi files, if any.
-		playLoadFiles(pEngine, pSetup->midifiles, false);
-	}
-
 	// Run the server, if requested.
 	if (pSetup->bServer) {
 	#ifdef CONFIG_FLUID_SERVER
@@ -2044,6 +2067,9 @@ bool qsynthMainForm::startEngine ( qsynthEngine *pEngine )
 	// All is right.
 	appendMessages(sPrefix + tr("Synthesizer engine started."));
 
+	// Play the midi files, if any...
+	playLoadFiles(pEngine, pSetup->midifiles, false);
+
 	return true;
 }
 
