@@ -396,8 +396,11 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			return false;
 		}
 		else if (sArg == "-v" || sArg == "--version") {
-			out << QString("Qt: %1\n")
-				.arg(qVersion());
+			out << QString("Qt: %1").arg(qVersion());
+		#if defined(QT_STATIC)
+			out << "-static";
+		#endif
+			out << '\n';
 			out << QString("FluidSynth: %1\n")
 				.arg(::fluid_version_str());
 			out << QString("%1: %2\n")
