@@ -1,7 +1,7 @@
 // qsynthOptionsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -46,9 +46,8 @@ static const char *g_pszDefName = QT_TRANSLATE_NOOP("qsynthOptionsForm", "(defau
 // qsynthOptionsForm -- UI wrapper form.
 
 // Constructor.
-qsynthOptionsForm::qsynthOptionsForm (
-	QWidget *pParent, Qt::WindowFlags wflags )
-	: QDialog(pParent, wflags)
+qsynthOptionsForm::qsynthOptionsForm ( QWidget *pParent )
+	: QDialog(pParent)
 {
 	// Setup UI struct...
 	m_ui.setupUi(this);
@@ -162,7 +161,7 @@ void qsynthOptionsForm::setup ( qsynthOptions *pOptions )
 		|| !font.fromString(m_pOptions->sMessagesFont))
 		font = QFont("Monospace", 8);
 	QPalette pal(m_ui.MessagesFontTextLabel->palette());
-	pal.setColor(QPalette::Background, pal.base().color());
+	pal.setColor(QPalette::Window, pal.base().color());
 	m_ui.MessagesFontTextLabel->setPalette(pal);
 	m_ui.MessagesFontTextLabel->setFont(font);
 	m_ui.MessagesFontTextLabel->setText(
@@ -232,6 +231,9 @@ void qsynthOptionsForm::accept (void)
 {
 	// Save options...
 	if (m_iDirtyCount > 0) {
+		const bool bOldStdoutCapture = m_pOptions->bStdoutCapture;
+		const bool bOldKeepOnTop     = m_pOptions->bKeepOnTop;
+		const int  iOldBaseFontSize  = m_pOptions->iBaseFontSize;
 		m_pOptions->sMessagesFont   = m_ui.MessagesFontTextLabel->font().toString();
 		m_pOptions->bMessagesLimit  = m_ui.MessagesLimitCheckBox->isChecked();
 		m_pOptions->iMessagesLimitLines = m_ui.MessagesLimitLinesComboBox->currentText().toInt();
@@ -282,6 +284,14 @@ void qsynthOptionsForm::accept (void)
 					QApplication::setPalette(pal);
 			}
 		}
+		// Warn if something will be only effective on next run...
+		if (( bOldStdoutCapture && !m_pOptions->bStdoutCapture) ||
+			(!bOldStdoutCapture &&  m_pOptions->bStdoutCapture) ||
+			( bOldKeepOnTop     && !m_pOptions->bKeepOnTop)     ||
+			(!bOldKeepOnTop     &&  m_pOptions->bKeepOnTop)     ||
+			(iOldBaseFontSize != m_pOptions->iBaseFontSize)) {
+			++iNeedRestart;
+		}
 		// Show restart message if needed...
 		if (iNeedRestart > 0) {
 			QMessageBox::information(this,
