@@ -1,7 +1,7 @@
 // qsynthOptionsForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -38,7 +38,7 @@ class qsynthOptionsForm : public QDialog
 public:
 
 	// Constructor.
-	qsynthOptionsForm(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
+	qsynthOptionsForm(QWidget *pParent = nullptr);
 	// Destructor.
 	~qsynthOptionsForm();
 
