@@ -1,7 +1,7 @@
 // qsynthSetupForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -747,18 +747,30 @@ void qsynthSetupForm::stabilizeForm (void)
 	m_ui.MidiChannelsSpinBox->setEnabled(bEnabled);
 	m_ui.MidiDumpCheckBox->setEnabled(bEnabled);
 	m_ui.VerboseCheckBox->setEnabled(bEnabled);
-	m_ui.MidiBankSelectLabel->setEnabled(bEnabled);
+	m_ui.MidiBankSelectTextLabel->setEnabled(bEnabled);
 	m_ui.MidiBankSelectComboBox->setEnabled(bEnabled);
 	m_ui.MidiNameTextLabel->setEnabled(bEnabled && (bAlsaEnabled | bCoreMidiEnabled));
 	m_ui.MidiNameComboBox->setEnabled(bEnabled && (bAlsaEnabled | bCoreMidiEnabled));
 
 	const bool bJackEnabled = (m_ui.AudioDriverComboBox->currentText() == "jack");
+	const bool bJackMultiEnabled = m_ui.JackMultiCheckBox->isChecked();
 	m_ui.AudioDeviceTextLabel->setEnabled(!bJackEnabled);
 	m_ui.AudioDeviceComboBox->setEnabled(!bJackEnabled);
 	m_ui.JackMultiCheckBox->setEnabled(bJackEnabled);
 	m_ui.JackAutoConnectCheckBox->setEnabled(bJackEnabled);
 	m_ui.JackNameTextLabel->setEnabled(bJackEnabled);
 	m_ui.JackNameComboBox->setEnabled(bJackEnabled);
+	if (bJackEnabled) {
+		m_ui.AudioChannelsTextLabel->setEnabled(bJackMultiEnabled);
+		m_ui.AudioChannelsSpinBox->setEnabled(bJackMultiEnabled);
+		m_ui.AudioChannelsSpinBox->setSingleStep(2);
+		m_ui.AudioChannelsSpinBox->setMinimum(2);
+
+		m_ui.AudioGroupsTextLabel->setEnabled(bJackMultiEnabled);
+		m_ui.AudioGroupsSpinBox->setEnabled(bJackMultiEnabled);
+		m_ui.AudioGroupsSpinBox->setSingleStep(2);
+		m_ui.AudioGroupsSpinBox->setMinimum(2);
+	}
 
 	m_ui.SoundFontOpenPushButton->setEnabled(true);
 	QTreeWidgetItem *pSelectedItem = m_ui.SoundFontListView->currentItem();
