@@ -1,7 +1,7 @@
 // qsynthSetupForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -42,7 +42,7 @@ class qsynthSetupForm : public QDialog
 public:
 
 	// Constructor.
-	qsynthSetupForm(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
+	qsynthSetupForm(QWidget *pParent = nullptr);
 	// Destructor.
 	~qsynthSetupForm();
 
